function [sigma_st,sigma_stp]=ieos802(p_bar,t,s)
%
% Calculates sigma(S,T) and sigma(S,T,p) for CTD-profilen,
%
% function [sigma_st,sigma_stp]=ieos802(p_bar,t,s)
%
% p_bar  pressure in bar
% t      temeprature in deg. C
% s      salinity in psu
%
% C. Schmid

% Look for cycles with dummies:
if length(t)==length(s)
   ii=find(t<= -900 | s <= -900);
   if length(ii),
      t(ii)=NaN*ones(size(t(ii)));,   s(ii)=t(ii);
   end
end
if ~length(find(~isnan(s))) | ~length(find(~isnan(t))),
   sigma_st=NaN*t;, sigma_stp=sigma_st;
   return
end
c1=999.842594;
c2=6.793952e-2;
c3=-9.095290e-3;
c4=1.001685e-4;
c5=-1.120083e-6;
c6=6.536332e-9;
c7=8.24493e-1;
c8=-4.0899e-3;
c9=7.6438e-5;
c10=-8.2467e-7;
c11=5.3875e-9;
c12=-5.72466e-3;
c13=1.0227e-4;
c14=-1.6546e-6;
c15=4.8314e-4;

d1=19652.21;
d2=148.4206;
d3=-2.327105;
d4=1.360477e-2;
d5=-5.155288e-5;
d6=3.239908;
d7=1.43713e-3;
d8=1.16092e-4;
d9=-5.77905e-7;
d10=8.50935e-5;
d11=-6.12293e-6;
d12=5.2787e-8;
d13=54.6746;
d14=-0.603459;
d15=1.09987e-2;
d16=-6.167e-5;
d17=7.944e-2;
d18=1.6483e-2;
d19=-5.3009e-4;
d20=2.2838e-3;
d21=-1.0981e-5;
d22=-1.6078e-6;
d23=1.91075e-4;
d24=-9.9348e-7;
d25=2.0816e-8;
d26=9.1697e-10;

%p_bar=p_bar(:);
%s=s(:);
%t=t(:);
t2 = t .* t;
t3 = t2 .* t;
t4 = t3 .* t;
t5 = t4 .* t;
s2 = s .* s;
s3 = s2 .* s;
sqrts3 = sqrt(s3);
p2 = p_bar .* p_bar;
p3 = p2 .* p_bar;

%     Berechnung von RHO(S,T,0)

rho_st = c1 + c2 * t + c3 * t2 + c4 * t3 + c5 * t4 + c6 * t5;
rho_st = rho_st + c7 * s + c8 * t .* s + c9 * t2 .* s + c10 * t3 .* s;
rho_st = rho_st + c11 * t4 .* s + c12 * sqrts3 + c13 * sqrts3 .* t;
rho_st = rho_st + c14 * sqrts3 .* t2 + c15 * s2;
sigma_st = rho_st - 1000;

%     Berechnung von K(S,T,p)

rk = d1 + d2 * t + d3 * t2 + d4 * t3 + d5 * t4 + d6 * p_bar;
rk = rk + d7 * t .* p_bar + d8 * t2 .* p_bar + d9 * t3 .* p_bar;
rk = rk + d10 * p2 + d11 * t .* p2 + d12 * t2 .* p2 + d13 * s;
rk = rk + d14 * t .* s + d15 * t2 .* s + d16 * t3 .* s + d17 * sqrts3;
rk = rk + d18 * t .* sqrts3 + d19 * t2 .* sqrts3 + d20 * p_bar .* s;
rk = rk + d21 * t .* p_bar .* s + d22 * t2 .* p_bar .* s;
rk = rk + d23 * p_bar .* sqrts3 + d24 * p2 .* s + d25 * t .* p2 .* s;
rk = rk + d26 * t2 .* p2 .* s;

%     Berechnung von RHO(S,T,p)
h1 = (1 - p_bar ./ rk);
h2 = 1 ./ rho_st;
alpha_stp = h2 .* h1;
h1 = (1 - p_bar ./ rk);
rho_stp = rho_st ./ (1 - p_bar ./ rk);
sigma_stp = rho_stp - 1000;
