function [data,variables,units,position,depth1,date1,time,status] = loadcdf(num,erst,ext,head,cvar)
%
% function [data,variables,units,position,depth,date1,time,status]=loadcdf(num,erst,ext,head,cvar);
%
% loads NETCDF-files, for Matlab 4.x, cs 12.9.1997
% adapted to Matlab 5.x, cs 17.1.1997
%
% status=1 -> input file does not exist
% status=2 -> input file is empty
% status=3 -> input file is not a netcdf file
%
% num    file number (may be empty, then erst must contain complete file name) 
% erst   first part of filename (or complete file name if length(num)==0 and
%        length(ext)=0)
% ext    extension of filename
% head   if 1 load header only (optional, default is 0)
% cvar   give names of variables to load (optional, default is all)
%        has to be cell array

data=[];, variables=[];, units=[];, position=[];, depth1=[];, date1=[];, time=[];
status=0;

if nargin<4, head=0;, end
if nargin<5, cvar='';, end
if num>999
   filenam=makenam(erst,num,ext,4);
elseif num>9999
   filenam=makenam(erst,num,ext,5);
elseif length(num);
   filenam=makenam(erst,num,ext,3);
else
   filenam=erst;
end

% check if file does not exist
if ~exist(filenam,'file'),
   fprintf('file %s does not exist\n',filenam), status=1;, return
end

% check if file size is ==0
f=dir(filenam);
if f.bytes==0
   fprintf('file %s is empty\n',f.name), status=2;, return
end

% check if file is not a netcdf file
f=netcdf(filenam,'nowrite');
if ~length(f)
   fprintf('file %s is not a netcdf file\n',f.name), status=3;, return
end
loadcdf_close(f)

if iscell(cvar)
   for k=1:length(cvar)
      s=ncload(filenam,cvar{k});
      t=s{1};, tmp{k}=t;
   end
   s=tmp;
else
   s=ncload(filenam);
end
l=0;
for k=1:length(s)
   tmp='';, str='';
   if strcmp(s{k},'xt_i'),                 tmp='longitude';
   elseif strcmp(s{k},'yt_j'),             tmp='latitude';
   elseif strcmp(s{k},'zt_k'),             tmp='depth';
   elseif strcmp(s{k},'conductivity'),     tmp='CNDC';
   elseif strcmp(s{k},'CNDC_qparm'),       tmp='CNDC_flag';
   elseif strcmp(s{k},'salinity'),         tmp='sal';
   elseif strcmp(s{k},'PSAL_qparm'),       tmp='sal_flag';
   elseif strcmp(s{k},'temperature'),      tmp='temp';
   elseif strcmp(s{k},'TEMP_qparm'),       tmp='temp_flag';
   elseif strcmp(s{k},'pressure'),         tmp='pres';
   elseif strcmp(s{k},'DEPH_qparm'),       tmp='pres_flag';
   elseif strcmp(s{k},'time'),             tmp='JULD';
   elseif strcmp(s{k},'woce_time'),
      str=s{k}; eval(['data=setfield(data,str,' s{k} ');'])
      str='time'; eval(['data=setfield(data,str,' s{k} ');'])
      h=floor(data.time/10000);,  m=floor((data.time-h*10000)/100);
      se=data.time-h*10000-m*100; data.time=[h+m/60+se/3600]/24;
      clear h m se
   elseif ~strcmp(s{k},'head'),
      tmp=s{k};
   end
   if length(tmp)
      eval([s{k} '=loadcdf_dummy(' s{k} ',s{k},filenam);'])
      eval([s{k} '=loadcdf_scale(' s{k} ',s{k},filenam);'])
      eval(['data=setfield(data,tmp,' s{k} ');'])
   end
   if ~strcmp(s{k},'head'),
      l=l+1;
      variables(l,1:length(s{k}))=s{k};
   end
   if ~strcmp(s{k},'time'), eval(['clear ' s{k}]), end
end
if isfield(data,'woce_date')
   y=floor(data.woce_date/10000);, m=floor((data.woce_date-y*10000)/100);
   d=data.woce_date-y*10000-m*100; data.dmy=[d m y];
   data=rmfield(data,'woce_date');
   clear m y d
end
if isfield(data,'woce_time_of_day')
   h=floor(data.woce_time_of_day/10000);,  m=floor((data.woce_time_of_day-h*10000)/100);
   se=data.woce_time_of_day-h*10000-m*100; data.time=[h+m/60+se/3600]/24;
   data=rmfield(data,'woce_time_of_day')
   clear h m se
end
if isfield(data,'time') & isfield(data,'dmy')
   data.time=dmy2rd(data.dmy)+data.time;
end
if isfield(data,'temp'), m=find(data.temp<-5);, data.temp(m)=NaN;, end
if isfield(data,'CNDC'), m=find(data.CNDC<0);, data.CNDC(m)=NaN;, end
if isfield(data,'u') & isfield(data,'v')
   f=netcdf(filenam,'nowrite'); r=f{'u'}.units(:); loadcdf_close(f)
   m=find(data.u==99999);, data.u(m)=NaN;
   m=find(data.v==99999);, data.v(m)=NaN;
   if ~findstr(r,'cm'), data.u=data.u*100;, data.v=data.v*100;, end
end
if isfield(data,'sal')
   tmp=round(data.sal);
   if ~length(find(tmp>=5 & tmp<=40)), 
      fprintf('NCEP ocean reanalysis data special\n')
      f=netcdf(filenam,'nowrite'); r=f{'salinity'}.units(:); loadcdf_close(f)
      if strcmp(r,'ppm-0.035')
         data.sal=(data.sal+0.035)*1000;
      else
         fprintf('LOADCDF - WARNING: do not know how to convert salinity - needed?\n')
      end
   end
   m=find(data.sal<0);, data.sal(m)=NaN;
end
if ~isfield(data,'lon') & ~isfield(data,'longitude')
   f=netcdf(filenam,'nowrite');
   gatts=att(f);
   for k = 1:length(gatts)
      if strcmp(name(gatts{k}),'latmin')
         data.latitude(1)=gatts{k}(:);
      elseif strcmp(name(gatts{k}),'latmax')
         data.latitude(2)=gatts{k}(:);
      elseif strcmp(name(gatts{k}),'lonmin')
         data.longitude(1)=gatts{k}(:);
      elseif strcmp(name(gatts{k}),'lonmax')
         data.longitude(2)=gatts{k}(:);
      elseif strcmp(name(gatts{k}),'latincr')
         dy=gatts{k}(:);
      elseif strcmp(name(gatts{k}),'lonincr')
         dx=gatts{k}(:);
      end
   end
   if isfield(data,'longitude')
      data.longitude=data.longitude(1)+dx/2:dx:data.longitude(2)-dx/2;
   end
   if isfield(data,'latitude')
      data.latitude=data.latitude(1)+dy/2:dy:data.latitude(2)-dy/2;
   end
   loadcdf_close(f)
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function data=loadcdf_dummy(data,s,filenam)
% function data=loadcdf_dummy(data,s,filenam);
% replace dummies with NaN if possible
f=netcdf(filenam,'nowrite');
dum=f{s}.missing_value(1);
if length(dum)==1 & ~ischar(data)
   data(find(data==dum))=NaN;
end
loadcdf_close(f)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function data=loadcdf_scale(data,s,filenam)
% function data=loadcdf_scale(data,s,filenam);
% rescale data if possible
f=netcdf(filenam,'nowrite');
a=f{s}.add_offset(1);
s=f{s}.scale_factor(1);
if length(a)==1 & length(s)==1,
   data=data*s+a;
end
loadcdf_close(f)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function loadcdf_close(f)
% function loadcdf_close(f)
if exist('close_netcdf')==2
   close_netcdf(f);
else
   close(f);
end

