function [lab,labp]=timlab(dmy,tim,arg3,arg4)
%
% possible calls:
% [lab,labp]=timlab(dmy,tim,choice,langu);
% [lab,labp]=timlab(dmy,tim,choice);
% [lab,labp]=timlab(dmy,tim,langu);
% [lab,labp]=timlab(dmy,tim);
%
% input
% dmy     matrix with day month and year in columns
% tim     time axis of plot
% choice  1 --> x-axis is time axis (default)
%         all other values y-axis is time axis
%         optional
% langu   'e' --> date is mm/dd/yyyy (default)
%         'g' --> date is dd.mm.yyyy
%         'es' --> date is mm/dd/yy
%         'gs' --> date is dd.mm.yy
%         optional
%
% output
% lab     xticklabels or yticklabels (mm-yy or dd-mm-yy)
% labp    position for xticklabels or yticklabels
%         (the 15th day of the months)
%

if nargin==2,
   choice=1;
   langu='e';
elseif nargin==3
   if ~isstr(arg3)
      choice=arg3;
      langu='e';
   else
      choice=1;
      langu=arg3;
   end
elseif nargin==4
   choice=arg3;
   langu=arg4;
else
   error('TIMLAB: Check number of input arguments')
end
langu=lower(langu);

if strcmp(langu(1),'e')
   lab_num=47;  % /
   lab1=['month' setstr(lab_num) 'year'];
   lab2=['month' setstr(lab_num) 'day' setstr(lab_num) 'year'];
elseif strcmp(langu(1),'g')
   lab_num=46;  % .
   lab1=['Monat' setstr(lab_num) 'Jahr'];
   lab2=['Tag' setstr(lab_num) 'Monat' setstr(lab_num) 'Jahr'];
else
   lab_num=45;  % -
   lab1=['month' setstr(lab_num) 'year'];
   lab2=['month' setstr(lab_num) 'day' setstr(lab_num) 'year'];
end
year0=0;
if length(langu)==2,
   if strcmp(langu(2),'s')
      year0=floor(dmy(1,3)/100)*100;
   end
end

tim=tim(:);
ii=find(diff(floor(tim)));
ii=ii+1-ceil(mean(diff(ii)));
ii=[ii ; max(ii)+ceil(mean(diff(ii)))];
k=find(ii>0);, ii=ii(k);
if length(ii)<length(tim),
   tim=tim(ii);, dmy=dmy(ii,:);
end
ii=find(dmy(:,1)==15);
if length(ii)<5,
   tim=floor(tim(1)):ceil(tim(length(tim)));
   dmy=rd2dmy(tim);
end
ii=find(dmy(:,1)==15);
if length(ii)>5 & length(ii)<10,
   lab=setstr(lab_num*ones(size(ii(:))));
   lab=[int2str(dmy(ii,2)) lab int2str(dmy(ii,3)-year0)];
   labp=tim(ii);
   lii=length(ii);
   if lii>15 & ~rem(lii,2),
      lab=lab([1:2:lii lii],:);
      labp=labp([1:2:lii lii]);
   elseif lii>15 & rem(lii,2),
      lab=lab([1:2:lii],:);
      labp=labp([1:2:lii]);
   end
   labs=lab1;
elseif length(ii)>=10 & length(ii)<=40,
   while length(ii)>10, ii=ii(1:2:length(ii));, end
   lab=setstr(lab_num*ones(size(ii(:))));
   lab=[int2str(dmy(ii,2)) lab int2str(dmy(ii,3)-year0)];
   labp=tim(ii);
   lii=length(ii);
   if lii>15 & ~rem(lii,2),
      labp=labp([1:2:lii lii]);
      lab=lab([1:2:lii lii],:);
   elseif lii>15 & rem(lii,2),
      lab=lab([1:2:lii],:);
      labp=labp([1:2:lii]);
   end
   k=length(labp);
   if k>=10,
      k=1:floor(k/10):k;
      labp=labp(k);
      lab=lab(k,:);
%      tmp=lab;, tmp(:,:)=32;, tmp(k,:)=lab(k,:);
%      lab=tmp;
   end
   labs=lab1;
elseif length(ii)>40,
   ii=ii(1:6:length(ii));
   while length(ii)>10, ii=ii(1:2:length(ii));, end
   lab=setstr(lab_num*ones(size(ii(:))));
   lab=[int2str(dmy(ii,2)) lab int2str(dmy(ii,3)-year0)];
   labp=tim(ii);
   lii=length(ii);
   if lii>15 & ~rem(lii,2),
      labp=labp([1:2:lii lii]);
      lab=lab([1:2:lii lii],:);
   elseif lii>15 & rem(lii,2),
      lab=lab([1:2:lii],:);
      labp=labp([1:2:lii]);
   end
   k=length(labp);
   if k>=10,
      k=1:floor(k/10):k;
      labp=labp(k);
      lab=lab(k,:);
%      tmp=lab;, tmp(:,:)=32;, tmp(k,:)=lab(k,:);
%      lab=tmp;
   end
   labs=lab1;
else
   dii=floor(length(tim)/7)+1;
   ii=1:dii:length(tim);
   lii=length(ii);
   lab=setstr(lab_num*ones(size(ii(:))));
   if strcmp(langu,'gs')
      lab=sprintf('%02d.%02d.%02d\n',[dmy(ii,1:2),dmy(ii,3)-year0]'); %'
   elseif strcmp(langu,'g')
      lab=sprintf('%02d.%02d.%04d\n',[dmy(ii,1:2),dmy(ii,3)-year0]'); %'
%OLD      lab=[int2str(dmy(ii,1)) lab int2str(dmy(ii,2)) lab int2str(dmy(ii,3)-year0)];
   elseif strcmp(langu,'es')
      lab=sprintf('%02d/%02d/%02d\n',[dmy(ii,[2 1]),dmy(ii,3)-year0]'); %'
   else
      lab=sprintf('%02d/%02d/%04d\n',[dmy(ii,[2 1]),dmy(ii,3)-year0]'); %'
%OLD      lab=[int2str(dmy(ii,2)) lab int2str(dmy(ii,1)) lab int2str(dmy(ii,3)-year0)];
   end
   k=find(lab==10);
   lab=reshape(lab,length(lab)/length(k),length(k))'; %'
   lab=lab(:,1:size(lab,2)-1);
%OLD   k=find(lab==32);, lab(k)='0';
   labp=tim(ii);
   labs=lab2;
end

if choice==1
   set(gca,'xticklabel',lab,'xtick',labp)
   xlabel(labs)
   a=axis;, dmy=rd2dmy(a(1):a(2));
   k=find(diff(dmy(:,3)));,k=[k(2:length(k));size(dmy,1)];, dmy=dmy(k,:);
   if length(k)>1
      dmy(:,1:2)=1;, x=dmy2rd(dmy);
      if size(x,1)==2, x(3)=NaN;, end
      hold on,h=plot([x x],a(3:4),'k');
   end
else
   set(gca,'yticklabel',lab,'ytick',labp)
   ylabel(labs)
   a=axis;, dmy=rd2dmy(a(3):a(4));
   k=find(diff(dmy(:,3)));,k=[k(2:length(k));size(dmy,1)];, dmy=dmy(k,:);
   if length(k)>1
      dmy(:,1:2)=1;, x=dmy2rd(dmy);
      if size(x,1)==2, x(3)=NaN;, end
      hold on,h=plot(a(1:2),[x x],'k');
   end
end
